# qt-range-slider [![Build Status](https://github.com/introkun/qt-range-slider/workflows/CI/badge.svg)](https://github.com/introkun/qt-range-slider/actions?query=workflow%3ACI) [![Coverage Status](https://coveralls.io/repos/github/introkun/qt-range-slider/badge.svg?branch=main&dummy=unused)](https://coveralls.io/github/introkun/qt-range-slider?branch=main) [![GitHub license](https://img.shields.io/github/license/introkun/qt-range-slider.svg)](https://github.com/introkun/qt-range-slider/blob/main/LICENSE) [![Github all releases](https://img.shields.io/github/downloads/introkun/qt-range-slider/total.svg)](https://GitHub.com/introkun/qt-range-slider/releases/)
